@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.5   update date: 2023-05-11
+# Version : 1.4.6   update date: 2023-06-07
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -15,27 +15,13 @@ while [[ $# -gt 0 ]]
 do
   key="$1"
   case $key in
-    -d)
-        DATADIR="$2";     shift 2
-        ;;
-    -i)
-        INSTALL_DIR="$2"; shift 2
-        ;;
-    -p)
-        USER_HOME="$2";   shift 2
-        ;;
-    -s)
-        DBS1GB="$2";      shift 2
-        ;;
-    -l)
-        GBASELOCALE="$2"; shift 2
-        ;;
-    -o)
-        SOFTONLY="$2";    shift 2
-        ;;
-    -u)
-        USER_NAME="$2";   shift 2
-        ;;
+    -d) DATADIR="$2";     shift 2 ;;
+    -i) INSTALL_DIR="$2"; shift 2 ;;
+    -p) USER_HOME="$2";   shift 2 ;;
+    -s) DBS1GB="$2";      shift 2 ;;
+    -l) GBASELOCALE="$2"; shift 2 ;;
+    -o) SOFTONLY="$2";    shift 2 ;;
+    -u) USER_NAME="$2";   shift 2 ;;
     *)
         cat <<!
 Usage:
@@ -64,7 +50,7 @@ else
 fi
 USER_UPPER=$(echo $USER_NAME|tr [a-z] [A-Z])
 USER_HOME=${USER_HOME:-/home/gbase}
-USER_PASS=GBase123
+USER_PASS=GBase123\$%
 INSTALL_DIR=${INSTALL_DIR:-/opt/gbase}
 GBASESERVER=gbase01
 GBASELOCALE=${GBASELOCALE:-zh_CN.utf8}
@@ -142,47 +128,45 @@ if [ ${NUMMEM:-0} -eq 0 ]; then
   exit 2
 elif [ $NUMMEM -le 2048 ]; then
   # mem less then 1G, use direct_io, only 2k buffpool
-  PAGESIZE="-k 2"
   CFG_DIRECT_IO=1
   CFG_LOCKS=50000
   CFG_SHMVIRTSIZE=384000
-  CFG_2KPOOL=50000 
+  CFG_2KPOOL=20000
+  CFG_16KPOOL=10000 
 elif [ $NUMMEM -le 4096 ]; then
   # mem less then 4G, use direct_io, only 2k buffpool
-  PAGESIZE="-k 2"
   CFG_DIRECT_IO=1
   CFG_LOCKS=200000
   CFG_SHMVIRTSIZE=512000
-  CFG_2KPOOL=100000
+  CFG_2KPOOL=50000
+  CFG_16KPOOL=20000 
 elif [ $NUMMEM -le 8192 ]; then
   # mem less then 8G, use direct_io, only 2k buffpool
-  PAGESIZE="-k 2"
   CFG_DIRECT_IO=1
   MUTI=$(expr $NUMMEM / 2000)
   [ $MUTI -eq 0 ] && MUTI=1
   CFG_LOCKS=1000000
-  CFG_SHMVIRTSIZE=$(awk -v n="$MUTI" 'BEGIN{print (n-1)*512000}')
-  CFG_2KPOOL=$(awk -v n="$MUTI" 'BEGIN{print (n-1)*500000}')
+  CFG_SHMVIRTSIZE=512000
+  CFG_2KPOOL=500000
+  CFG_16KPOOL=100000
 elif [ $NUMMEM -le 32768 ]; then
   # mem >8G && < 32G, not use direct_io, use 2k & 16k buffpool
-  PAGESIZE="-k 16"
   CFG_DIRECT_IO=0
   MUTI=$(expr $NUMMEM / 8000)
-  [ $MUTI -eq 0 ] && MUTI=1
+  [ $MUTI -eq 0 ] && MUTI=2
   CFG_LOCKS=5000000
   CFG_SHMVIRTSIZE=$(awk -v n="$MUTI" 'BEGIN{print (n-1)*1024000}')
   CFG_2KPOOL=500000
-  CFG_16KPOOL=$(awk -v n="$MUTI" 'BEGIN{print (n-1)*250000}')
+  CFG_16KPOOL=$(awk -v n="$MUTI" 'BEGIN{print (n-1)*200000}')
 else
   # mem > 32G
-  PAGESIZE="-k 16"
   CFG_DIRECT_IO=0
   CFG_LOCKS=5000000
   CFG_SHMVIRTSIZE=4096000
   CFG_2KPOOL=1000000
   CFG_16KPOOL=1000000
 fi
-
+PAGESIZE="-k 16"
 CFG_SHMADD=$(expr ${CFG_SHMVIRTSIZE:-1024000} / 4)
 CFG_SHMTOTAL=$(expr $NUMMEM \* 900)
 
@@ -501,7 +485,7 @@ if [ $NUMMEM -le 4096 ]; then
   sed -i "s#^DS_NONPDQ_QUERY_MEM.*#DS_NONPDQ_QUERY_MEM 32000#g" $CFGFILE
 fi
 # dynamic value
-sed -i "s#^NETTYPE.*#NETTYPE soctcp,${CFG_NETPOOL},200,CPU#g" $CFGFILE
+sed -i "s#^NETTYPE.*#NETTYPE soctcp,${CFG_NETPOOL},200,NET#g" $CFGFILE
 sed -i "s#^VPCLASS.*cpu.*#VPCLASS cpu,num=${CPUVP},noage#g" $CFGFILE
 sed -i "s#^DIRECT_IO.*#DIRECT_IO ${CFG_DIRECT_IO}#g" $CFGFILE
 sed -i "s#^LOCKS.*#LOCKS ${CFG_LOCKS}#g" $CFGFILE
@@ -510,8 +494,11 @@ sed -i "s#^SHMADD.*#SHMADD ${CFG_SHMADD}#g" $CFGFILE
 sed -i "s#^SHMTOTAL.*#SHMTOTAL ${CFG_SHMTOTAL}#g" $CFGFILE
 
 sed -i "s#^BUFFERPOOL.*size=2.*#BUFFERPOOL size=2K,buffers=${CFG_2KPOOL},lrus=8,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
-if [ $NUMMEM -ge 8192 ]; then
-  sed -i "s#^BUFFERPOOL.*size=16.*#BUFFERPOOL size=16K,buffers=${CFG_16KPOOL},lrus=64,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
+sed -i "s#^BUFFERPOOL.*size=16.*#BUFFERPOOL size=16K,buffers=${CFG_16KPOOL},lrus=64,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
+
+MSG_DATE=$(su - gbasedbt -c "onstat -c MSG_DATE 2>/dev/null")
+if [ x"${MSG_DATE}" = x ]; then
+  sed -i "/^MSGPATH/a\MSG_DATE 1" $CFGFILE
 fi
 
 ####### restart database
