@@ -3,7 +3,7 @@
 # Filename: CleanAll.sh
 # Function: Clean GBase 8s Auto Install.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.3   update date: 2022-08-12
+# Version : 1.4.5   update date: 2023-05-11
 ##################################################################
 ##### Define Parameter
 ##### Get Parameter
@@ -45,7 +45,7 @@ ps -ef | awk '/oninit/ && $3==1{print "kill -9 "$2}' | sh 2>/dev/null
 userdel -rf ${USER_NAME} 2>/dev/null
 groupdel ${USER_NAME} 2>/dev/null
 
-if [ -d $INSTALL_DIR -a ! x$INSTALL_DIR = x/ ]; then
+if [ -d "$INSTALL_DIR" -a ! x$INSTALL_DIR = x/ ]; then
   read -p "Drop directory [$INSTALL_DIR]? [Y/N] " ISDROP 
   if [ x"${ISDROP}" = x"Y" -o x"${ISDROP}" = x"y" ];then 
     rm -rf ${INSTALL_DIR} 2>/dev/null
